#### 1.0.0 version update
* 移除旧的类
* 增加Elements
* 完善使用文档


#### 0.6.4 version update
* 修复bug
* 增加CSSElement API

#### 0.6.3 version update
* add keys  操作

#### 0.6.2 version update
* 通过 colorama 实现log打印
* 执行增加元素高亮

#### 0.6.0 version update

* 增加 NewPageElement类，不向后兼容。

#### 0.5.3 version update

* bug fix
* add cookie api

#### 0.5.2 version update

* Increase log switch


#### 0.5.1 version update

* Adding new methods
* Optimize log outputg


#### 0.5.0 version update

* So it reimplements the CSSElement class
* Add logging

#### 0.3.7 version update

* fix timeout bug.


#### 0.3.6 version update

* Adds CSSElement class.

#### 0.3.5 version update

* Adds a red border to the element of the operation


#### 0.3.2 version update

* Add a new JavaScript API


#### 0.3.1 version update

* Add a new appium API
* If you use CSS positioning, border the elements of the operation

#### 0.3.0 version update

* Project code refactoring.

#### 0.2.3 version update

* adding javascript operating api

#### 0.2.2 version update

* To better fit the project, update the name is poium.

#### 0.2.1 version update

* adding appium support

#### 0.1.5 version update

* new common mouse operations

#### 0.1.4 version update

* adding class PageWait

#### 0.1.3 version update

* adding class PageSelect

#### 0.1 version update

* page object based on selenium.
